@@ -428,6 +428,8 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     self.action_group.add_actions([
         ('RefreshAll', gtk.STOCK_REFRESH, None,
          None, 'Refresh all', self._refreshTopLevel),
+        # Translators: Refresh current tree node's children.
+        #
         ('RefreshCurrent', gtk.STOCK_JUMP_TO, _('Refresh _Current'),
          None, 'Refresh selected node\'s children', self._refreshCurrentLevel)])  
 
@@ -490,10 +492,10 @@ class AccessibleTreeView(gtk.TreeView, Tools):
       # Bad karma
       return
     if self.model.isInModel(event.source):
-      path = self.model.getAccPath(event.source)
-      if path:
+      try:
+        path = self.model.getAccPath(event.source)
         iter = self.model.get_iter(path)
-      else:
+      except:
         iter = None
       if (event.source == self.desktop) or \
             (path and self.model[path][COL_FILLED]):
@@ -632,7 +634,7 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     path = self.model.getAccPath(acc)
     if not path:
       return
-    if len(path) > 1:
+    if len(path) >= 1:
       self.selectNodeAtPath(path)
       self.node.tree_path = list(path[1:])
 
@@ -677,7 +679,8 @@ class AccessibleTreeView(gtk.TreeView, Tools):
     @param path: Path to select.
     @type path: tuple
     '''
-    self.expand_to_path(path[:-1])
+    if len(path) > 1:
+      self.expand_to_path(path[:-1])
     self.scroll_to_cell(path)
     selection = self.get_selection()
     selection.select_path(path)
